(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('rxjs'), require('@angular/core'), require('rxjs/operators'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define('ngx-monaco', ['exports', 'rxjs', '@angular/core', 'rxjs/operators', '@angular/common'], factory) :
	(factory((global['ngx-monaco'] = {}),global.rxjs,global.ng.core,global.Rx.Observable.prototype,global.ng.common));
}(this, (function (exports,rxjs,core,operators,common) { 'use strict';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0
THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.
See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */









function __values(o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m) return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
}

function fromDisposable(source) {
    return rxjs.Observable.create(function (observer) {
        var disposable = source(function (e) {
            observer.next(e);
        });
        return function () { return disposable.dispose(); };
    });
}
var COMPLETION_PROVIDERS = new core.InjectionToken('Completion Provider');
var MONACO_EDITOR_OPTIONS = new core.InjectionToken('Monaco Editor Options');
var MonacoEditorService = /** @class */ (function () {
    function MonacoEditorService(completionProviders, editorOptions, zone) {
        this.completionProviders = completionProviders;
        this.editorOptions = editorOptions;
        this.zone = zone;
        this.onFileChange = new rxjs.Subject();
        this.fileChange$ = this.onFileChange.asObservable();
        this.bootstrap$ = rxjs.Observable.create(function (observer) {
            var script = document.createElement('script');
            script.type = 'text/javascript';
            script.src = 'libs/vs/loader.js';
            script.onload = function () {
                window.require.config({ paths: { vs: 'libs/vs' } });
                window.require(['vs/editor/editor.main'], function () {
                    observer.next();
                });
            };
            document.body.appendChild(script);
        }).pipe(operators.shareReplay(1));
    }
    Object.defineProperty(MonacoEditorService.prototype, "editor", {
        get: function () {
            return this.monacoEditor;
        },
        enumerable: true,
        configurable: true
    });
    MonacoEditorService.prototype.registerCompletionProviders = function () {
        if (!this.completionProviders) {
            return;
        }
        try {
            for (var _a = __values(this.completionProviders), _b = _a.next(); !_b.done; _b = _a.next()) {
                var completionProvider = _b.value;
                monaco.languages.registerCompletionItemProvider(completionProvider.language, completionProvider);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_1) throw e_1.error; }
        }
        var e_1, _c;
    };
    MonacoEditorService.prototype.registerModelChangeListener = function (file, model) {
        var _this = this;
        var destroy = fromDisposable(model.onWillDispose.bind(model)).pipe(operators.take(1));
        fromDisposable(model.onDidChangeContent.bind(model))
            .pipe(operators.map(function () { return model.getValue(); }), operators.takeUntil(destroy))
            .subscribe(function (content) {
            _this.zone.run(function () {
                _this.onFileChange.next(Object.assign({}, file, { content: content }));
            });
        });
    };
    MonacoEditorService.prototype.disposeModels = function () {
        if (!window.monaco) {
            return;
        }
        try {
            for (var _a = __values(monaco.editor.getModels()), _b = _a.next(); !_b.done; _b = _a.next()) {
                var model = _b.value;
                model.dispose();
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_2) throw e_2.error; }
        }
        var e_2, _c;
    };
    MonacoEditorService.prototype.load = function (container, options) {
        var _this = this;
        if (options === void 0) { options = {}; }
        var editorOptions = options.editor || this.editorOptions || {};
        return this.bootstrap$.pipe(operators.tap(function () {
            _this.disposeModels();
            _this.monacoEditor = monaco.editor.create(container.nativeElement, Object.assign({ theme: options.theme }, editorOptions));
            _this.registerCompletionProviders();
            if (_this.file) {
                _this.open(_this.file);
            }
        }));
    };
    MonacoEditorService.prototype.open = function (file) {
        this.file = file;
        if (!this.monacoEditor) {
            return;
        }
        var uri = monaco.Uri.file(file.uri);
        var model = monaco.editor.getModel(uri);
        if (model) {
            if (file.language && model.getModeId() !== file.language) {
                model.dispose();
                model = undefined;
            }
            else {
                model.setValue(file.content);
            }
        }
        if (!model) {
            model = monaco.editor.createModel(file.content, file.language, uri);
            this.registerModelChangeListener(file, model);
        }
        this.monacoEditor.setModel(model);
    };
    MonacoEditorService.prototype.updateOptions = function (options) {
        if (this.monacoEditor) {
            this.monacoEditor.updateOptions(options);
        }
    };
    MonacoEditorService.prototype.setTheme = function (theme) {
        if (window.monaco) {
            monaco.editor.setTheme(theme);
        }
    };
    return MonacoEditorService;
}());
MonacoEditorService.decorators = [
    { type: core.Injectable },
];
MonacoEditorService.ctorParameters = function () { return [
    { type: Array, decorators: [{ type: core.Optional }, { type: core.Inject, args: [COMPLETION_PROVIDERS,] },] },
    { type: undefined, decorators: [{ type: core.Optional }, { type: core.Inject, args: [MONACO_EDITOR_OPTIONS,] },] },
    { type: core.NgZone, },
]; };
var MonacoEditorDirective = /** @class */ (function () {
    function MonacoEditorDirective(monacoEditorService, editorRef) {
        this.monacoEditorService = monacoEditorService;
        this.editorRef = editorRef;
        this.ready = new core.EventEmitter();
        this.fileChange = new core.EventEmitter();
        this.resize$ = new rxjs.Subject();
        this.destroy$ = new rxjs.Subject();
    }
    MonacoEditorDirective.prototype.onResize = function () {
        this.resize$.next();
    };
    MonacoEditorDirective.prototype.open = function (file) {
        this.monacoEditorService.open(file);
    };
    MonacoEditorDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.monacoEditorService.load(this.editorRef, {
            theme: this.theme,
            editor: this.options
        }).subscribe(function () {
            _this.ready.emit();
        });
        this.monacoEditorService.fileChange$.pipe(operators.takeUntil(this.destroy$)).subscribe(function (file) {
            _this.fileChange.emit(file);
        });
        this.resize$.pipe(operators.filter(function () { return Boolean(_this.monacoEditorService.editor); }), operators.map(function () { return ({ width: _this.editorRef.nativeElement.clientWidth, height: _this.editorRef.nativeElement.clientHeight }); }), operators.distinctUntilChanged(function (a, b) { return a.width === b.width && a.height === b.height; }), operators.debounceTime(50), operators.takeUntil(this.destroy$)).subscribe(function (dimension) {
            _this.monacoEditorService.editor.layout(dimension);
        });
    };
    MonacoEditorDirective.prototype.ngOnDestroy = function () {
        this.destroy$.next();
    };
    MonacoEditorDirective.prototype.ngOnChanges = function (changes) {
        if (changes["options"]) {
            this.monacoEditorService.updateOptions(changes["options"].currentValue);
        }
        if (changes["theme"]) {
            this.monacoEditorService.setTheme(changes["theme"].currentValue);
        }
        if (changes["file"]) {
            this.open(changes["file"].currentValue);
        }
    };
    MonacoEditorDirective.prototype.ngAfterViewChecked = function () {
        this.resize$.next();
    };
    return MonacoEditorDirective;
}());
MonacoEditorDirective.decorators = [
    { type: core.Directive, args: [{
                selector: 'monaco-editor,[monaco-editor]'
            },] },
];
MonacoEditorDirective.ctorParameters = function () { return [
    { type: MonacoEditorService, },
    { type: core.ElementRef, },
]; };
MonacoEditorDirective.propDecorators = {
    "theme": [{ type: core.Input },],
    "file": [{ type: core.Input },],
    "options": [{ type: core.Input },],
    "ready": [{ type: core.Output },],
    "fileChange": [{ type: core.Output },],
    "onResize": [{ type: core.HostListener, args: ['window:resize',] },],
};
var MonacoEditorModule = /** @class */ (function () {
    function MonacoEditorModule() {
    }
    MonacoEditorModule.forRoot = function (config) {
        if (config === void 0) { config = {}; }
        return {
            ngModule: MonacoEditorModule,
            providers: [
                MonacoEditorService,
                { provide: MONACO_EDITOR_OPTIONS, useValue: config.options || {} }
            ]
        };
    };
    return MonacoEditorModule;
}());
MonacoEditorModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    common.CommonModule
                ],
                declarations: [
                    MonacoEditorDirective
                ],
                exports: [
                    MonacoEditorDirective
                ]
            },] },
];

exports.MonacoEditorModule = MonacoEditorModule;
exports.MonacoEditorDirective = MonacoEditorDirective;
exports.MonacoEditorService = MonacoEditorService;
exports.COMPLETION_PROVIDERS = COMPLETION_PROVIDERS;
exports.MONACO_EDITOR_OPTIONS = MONACO_EDITOR_OPTIONS;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-monaco.umd.js.map
